translate.convert.xliff2oo.oofilteroptions

Package translate :: Package convert :: Module xliff2oo :: Class oofilteroptions |
[hide private]
[frames] | no frames]

# Class oofilteroptions

source code

Class Variables | [hide private]
| error = `['variables', 'xmltags', 'escapes']`
| warning = `['blank']`
| alwayswarn = `True`
| limitfilters = `error+ warning`
| excludefilters = `{}`
| includefuzzy = `False` Parse an instance of this class from the start of the given string.
| includereview = `False` Parse an instance of this class from the start of the given string.
| autocorrect = `False` Parse an instance of this class from the start of the given string.